<?php
require_once( 'abstract_oc_object.php' );

class OcArticle extends AbstractOcObject {


	private $prop_data;
	private $wp_post_article;

	public function __construct() {
		$this->wp_post_article = false;
	}

	/*
	 * Overloaded dynamic Setter
	 * Origin: abstract base class
	 * Will use Mapped properties in prop_array if they exists
	 */
	public function __set( $name, $value ) {

		if ( $name === 'url' ) {
			if ( isset( $value[0] ) && strpos( $value[0], 'http://' ) === false && $value[0] != "" ) {

				$value[0] = 'http://' . $value[0];

			}
		}

        $this->prop_data[ $name ] = $value;
	}

	/*
	 * Overloaded dynamic getter
	 * Origin: abstract base class
	 * Will use Mapped properties in prop_array if they exists
	 */
	public function __get( $name ) {
		$name = strtolower( $name );
		if ( isset( $this->prop_data[$name] ) ) {
			return $this->prop_data[$name];
		} else {
			return array();
		}
	}

	/*
	 * Isset overload for magic props
	 * Will look for prop in prop_data array
	 */
	public function __isset( $name ) {
		return isset( $this->prop_data[$name] );
	}

	/*
	 * Public funtion to strip tags from text
	 * @scope public
	 * @param string - name of OC-text prop
	 * @return string with stript tags
	 */
	public function get_normalized_text( $name ) {

		$text = $this->$name;
		$text = preg_replace( '/subheadline1/', 'h4', $text[0] );
		//$text = preg_replace( '/subheadline2/', 'h5', $text[0] );
		//$text = preg_replace( '/subheadline3/', 'h6', $text[0] );
		//$text = preg_replace( '/subheadline4/', 'h6', $text[0] );
		$text = preg_replace( '/<\/?body>/', '', $text );

		return $text;
	}

	/*
	 * Public funtion to strip tags from multi value props
	 * @scope public
	 * @param string - name of OC-prop to clean
	 * @return array with clean props
	 */
	public function get_cleaned_multi_value_prop( $name ) {
		$body = array();

		if ( isset( $this->$name ) ) {
			foreach ( $this->$name as $value ) {
				array_push( $body, strip_tags( $value, '<p><a>' ) );
			}
		}

		return $body;
	}

	/**
	 * Public helper function to get content, instead of array, from prop
	 * @param  string property name
	 * @return string property content or empty
	 */
	public function get_value( $name ) {
		$name = strtolower( $name );
		if ( isset( $this->prop_data[$name][0] ) ) {
			return $this->prop_data[$name][0];
		} else {
			return '';
		}
	}

	/**
	 * Public function to get "The post" wp object
	 * @return WP Post-type object
	 */
	public function get_post(){

		$article = $this->wp_post_article;

		if ( !$article ) {
			$article = OcUtilities::get_article_post_by_uuid( $this->uuid[0] );
			$this->wp_post_article = $article;
		}

		return $article;
	}

	/*
	 * Public funtion to get article permalink
	 * @scope public
	 * @return article permalink
	 */
	public function get_permalink() {
		$article = $this->get_post();
		return !$article ? '' : get_permalink( $article->ID );
	}

	/*
	 * Public function to get article headline for the device used accessing it.
	 * @scope public
	 * @return string headline
	 */
	public function get_device_headline() {
		$device_headline	= '';

		if( OcUtilities::is_mobile() &&  !OcUtilities::is_tablet() &&	 isset( $this->mobile_headline[0] ) && $this->mobile_headline[0] !== '' ) {
    		$device_headline = $this->mobile_headline[0];
		}
		else if( OcUtilities::is_tablet() && isset( $this->tablet_headline[0] ) && $this->tablet_headline[0] !== '' ) {
    		$device_headline = $this->tablet_headline[0];
		}
		else if( isset( $this->web_headline[0] ) && $this->web_headline[0] !== '' ) {
			$device_headline = $this->web_headline[0];
		}
		else if( isset( $this->headline[0] ) && $this->headline[0] !== '' ) {
			$device_headline = $this->headline[0];
		}
		return $device_headline;
	}

	/*
	 * Public funtion to get article comment count
	 * @scope public
	 * @return article comment count
	 */
	public function get_comment_count() {
        $article = $this->get_post();
        $key = md5( 'article_ccount_' . $article->ID );
        
        if( false === ( $comments = get_transient( $key ) ) ) {
        	$comments = wp_count_comments( $article->ID );
        	set_transient( $key, $comments, 60 * 30 );
        }
        
        return $comments->total_comments;
    }

    /*
	 * Public funtion to get article comment link
	 * @scope public
	 * @return article comment link
	 */
    public function get_comment_link() {

        $article = $this->get_post();
        return get_comments_link( $article->ID );
    }

    /*
     * Public function to get the view count for the article
     * @scope public
     * @return count int
     */
    public function get_view_count() {

    	$article = $this->get_post();
    	$count = get_post_meta( $article->ID, EveryStats::EVERY_STATS_COUNT_KEY, true );
    	if( $count === '' ) {
    		return 0;
    	}
    	
    	return $count;
    }


    /**
     * Returns all current properties on object
     * @return mixed
     */
    public function get_all_properties() {
        return $this->prop_data;
    }
}